<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>RecentFiles</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Naloži/Shrani</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translation>Nedavne datoteke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translation>&amp;Počisti seznam</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;Recent</source>
        <translation>Odpri &amp;nedavno</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>Obseg zgodovine nedavnih datotek:</translation>
    </message>
</context>
</TS>
